@@ -53,7 +53,6 @@ class RestAPI(object):
 		self.__plans__ = {
 			"developer": {
 				"plan_id":None,
-				"price_id":None,
 				"rate_limit":None,
 				"rate_reset":None,
 				"api_keys":[],
@@ -61,23 +60,20 @@ class RestAPI(object):
 			},
 			"free": {
 				"plan_id":None,
-				"price_id":None,
 				"rate_limit":3,
 				"rate_reset":1, # in days.
 				"api_keys":[],
 				"rank":1,
 			},
 			"premium": {
-				"plan_id":"prod_I41OYB.....",
-				"price_id":"price_1Hp9g.....",
+				"plan_id":"price_1Hp9g.....", # price id from stripe plan.
 				"rate_limit":10000,
 				"rate_reset":30, # in days.
 				"api_keys":[],
 				"rank":2,
 			},
 			"pro": {
-				"plan_id":"prod_IPiu7a.....",
-				"price_id":"price_1HTnI.....",
+				"plan_id":"price_1HTnI.....", # price id from stripe plan.
 				"rate_limit":25000,
 				"rate_reset":30, # in days.
 				"api_keys":[],
